/*
 * Fabric3
 * Copyright (c) 2009 Metaform Systems
 *
 * Fabric3 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version, with the
 * following exception:
 *
 * Linking this software statically or dynamically with other
 * modules is making a combined work based on this software.
 * Thus, the terms and conditions of the GNU General Public
 * License cover the whole combination.
 *
 * As a special exception, the copyright holders of this software
 * give you permission to link this software with independent
 * modules to produce an executable, regardless of the license
 * terms of these independent modules, and to copy and distribute
 * the resulting executable under terms of your choice, provided
 * that you also meet, for each linked independent module, the
 * terms and conditions of the license of that module. An
 * independent module is a module which is not derived from or
 * based on this software. If you modify this software, you may
 * extend this exception to your version of the software, but
 * you are not obligated to do so. If you do not wish to do so,
 * delete this exception statement from your version.
 *
 * Fabric3 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the
 * GNU General Public License along with Fabric3.
 * If not, see <http://www.gnu.org/licenses/>.
 *
 * ----------------------------------------------------
 *
 * Portions originally based on Apache Tuscany 2007
 * licensed under the Apache 2.0 license.
 *
 */
package org.fabric3.spi.component;

import java.net.URI;
import javax.xml.namespace.QName;

import org.fabric3.host.monitor.Monitorable;

/**
 * The runtime instantiation of an SCA component
 *
 * @version $$Rev: 9091 $$ $$Date: 2010-06-05 14:56:50 +0000 (Sat, 05 Jun 2010) $$
 */
public interface Component extends Monitorable {

    /**
     * Returns the QName of the deployable composite this component was deployed with.
     *
     * @return the group containing this component
     */
    QName getDeployable();

    /**
     * Returns the component URI.
     *
     * @return the component URI
     */
    URI getUri();

    /**
     * Returns the classloader the component is associated with.
     *
     * @return the classloader the component is associated with.
     */
    URI getClassLoaderId();

    /**
     * Sets the classloader the component is associated with.
     *
     * @param classLoaderId the classloader the component is associated with.
     */
    void setClassLoaderId(URI classLoaderId);

    /**
     * Starts the component;
     *
     * @throws ComponentException if an error occurs starting the component
     */
    void start() throws ComponentException;

    /**
     * Stops the component.
     *
     * @throws ComponentException if an error occurs stopping the component
     */
    void stop() throws ComponentException;

}
